@@ -49,4 +49,6 @@ class TBwr:
             global_step=    step,
             bins=           "tensorflow")
 
-    def flush(self): self.sw.flush()
+    def flush(self):
+        if self.sw:
+            self.sw.flush()
